=======
History
=======

`0.4.0`_ (2018-03-17)
----------------------

Added
~~~~~

* CLI entry point via ``taika``.
* GitLab folder for issues and merge requests customization.
* Spell checker for the documentation.

Changed
~~~~~~~

None.

Deprecated
~~~~~~~~~~

None.

Removed
~~~~~~~

* Certain folders that should be untracked.
* Unused badges on the README.

Fixed
~~~~~

None.

Security
~~~~~~~~

None.

0.3.0 (2018-03-15)
------------------

Necessary BUMP to wrap my head around the schema.

0.2.1 (2018-03-15)
------------------

Added
~~~~~

* GitLab Continuous Integration.
* Configuration for pytest: now the working directory is the ``tests`` folder.

Changed
~~~~~~~

None.

Deprecated
~~~~~~~~~~

None.

Removed
~~~~~~~

* Travis Continuous Integration.

Fixed
~~~~~

None.

Security
~~~~~~~~

None.

0.2.0 (2018-03-15)
------------------

Added
~~~~~

* Added the skeleton for the project.
* Added the first functions and functionality via API.

Changed
~~~~~~~

None.

Deprecated
~~~~~~~~~~

None.

Removed
~~~~~~~

None.

Fixed
~~~~~

None.

Security
~~~~~~~~

None.


0.1.X (YYYY-MM-DD)
------------------

This versions correspond to older taika versions that I've uploaded to PyPi.


.. _0.4.0: https://gitlab.com/hectormartinez/taika/tags/v0.4.0
